==> react-atom-button-1.56.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";
import cx from 'classnames';
import { CLASS, COLORS, DESIGNS, ICON_POSITIONS, GROUP_POSITIONS, MODIFIERS, OWN_PROPS, SIZES, TYPES } from './config';
import Button from './Button';
import ButtonIcon from './ButtonIcon';
import ButtonSpinnerIcon from './buttonSpinnerIcon';

var createClasses = function createClasses(array, sufix) {
  if (sufix === void 0) {
    sufix = '';
  }

  return array.reduce(function (res, key) {
    var _extends2;

    return _extends({}, res, (_extends2 = {}, _extends2[key] = CLASS + "--" + key + sufix, _extends2));
  }, {});
};

var CLASSES = createClasses([].concat(TYPES, Object.values(DESIGNS), MODIFIERS, Object.values(SIZES), ['empty']));
var COLOR_CLASSES = createClasses(COLORS, 'Color');
/**
 * Get props cleaning out AtomButton own props
 * @param  {Object} props
 * @return {Object}
 */

var cleanProps = function cleanProps(props) {
  var newProps = _extends({}, props);

  OWN_PROPS.forEach(function (key) {
    return delete newProps[key];
  });
  return newProps;
};
/**
 * Get modifiers to apply according to props
 * @param  {Object} props
 * @return {Array<String>}
 */


var getModifiers = function getModifiers(props) {
  return Object.keys(props).filter(function (name) {
    return props[name] && MODIFIERS.includes(name);
  });
};

var getPropsWithDefaultValues = function getPropsWithDefaultValues(props) {
  var color = props.color,
      design = props.design,
      type = props.type; // if color or design are defined, use them with the passed or default value

  if (color || design) {
    if (design !== DESIGNS.LINK) {
      color = color || 'primary';
    }

    design = design || DESIGNS.SOLID;
  } else {
    type = type || 'primary';
  }

  return _extends({
    color: color,
    design: design,
    type: type
  }, props);
};

var AtomButton = function AtomButton(props) {
  var _cx;

  var _getPropsWithDefaultV = getPropsWithDefaultValues(props),
      color = _getPropsWithDefaultV.color,
      children = _getPropsWithDefaultV.children,
      className = _getPropsWithDefaultV.className,
      focused = _getPropsWithDefaultV.focused,
      groupPosition = _getPropsWithDefaultV.groupPosition,
      leftIcon = _getPropsWithDefaultV.leftIcon,
      rightIcon = _getPropsWithDefaultV.rightIcon,
      size = _getPropsWithDefaultV.size,
      design = _getPropsWithDefaultV.design,
      title = _getPropsWithDefaultV.title,
      disabled = _getPropsWithDefaultV.disabled,
      isLoading = _getPropsWithDefaultV.isLoading,
      loadingText = _getPropsWithDefaultV.loadingText,
      type = _getPropsWithDefaultV.type,
      _getPropsWithDefaultV2 = _getPropsWithDefaultV.loader,
      loader = _getPropsWithDefaultV2 === void 0 ? /*#__PURE__*/_jsx(ButtonSpinnerIcon, {}) : _getPropsWithDefaultV2;

  var classNames = cx(CLASS, !type && COLOR_CLASSES[color], !type && CLASSES[design], type && CLASSES[type], groupPosition && CLASS + "-group " + CLASS + "-group--" + groupPosition, groupPosition && focused && CLASS + "-group--focused", size && CLASSES[size], getModifiers(_extends({}, props, {
    disabled: disabled || isLoading
  })).map(function (key) {
    return CLASSES[key];
  }), !children && CLASSES.empty, (_cx = {}, _cx[CLASS + "--loading"] = isLoading, _cx), className);
  var newProps = cleanProps(props);
  return /*#__PURE__*/_jsx(Button, _extends({}, newProps, {
    className: classNames,
    title: title,
    disabled: disabled || isLoading,
    children: /*#__PURE__*/_jsx("span", {
      className: CLASS + "-inner",
      children: isLoading ? /*#__PURE__*/_jsxs(_Fragment, {
        children: [/*#__PURE__*/_jsx(ButtonIcon, {
          position: loadingText ? ICON_POSITIONS.LEFT : ICON_POSITIONS.CENTER,
          size: size,
          children: loader
        }), children && loadingText ? loadingText : /*#__PURE__*/_jsx("span", {
          className: CLASS + "-text",
          children: children
        })]
      }) : /*#__PURE__*/_jsxs(_Fragment, {
        children: [/*#__PURE__*/_jsx(ButtonIcon, {
          position: ICON_POSITIONS.LEFT,
          size: size,
          children: leftIcon
        }), leftIcon || rightIcon ? /*#__PURE__*/_jsx("span", {
          className: CLASS + "-text",
          children: children
        }) : children, /*#__PURE__*/_jsx(ButtonIcon, {
          position: ICON_POSITIONS.RIGHT,
          size: size,
          children: rightIcon
        })]
      })
    })
  }));
};

AtomButton.displayName = 'AtomButton';
export default AtomButton;
export { GROUP_POSITIONS as atomButtonGroupPositions };
export { COLORS as atomButtonColors };
export { DESIGNS as atomButtonDesigns };
export { SIZES as atomButtonSizes };
export { TYPES as atomButtonTypes };

==> react-atom-button-1.57.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";
import cx from 'classnames';
import { CLASS, COLORS, DESIGNS, ALIGNMENT, ICON_POSITIONS, GROUP_POSITIONS, MODIFIERS, OWN_PROPS, SIZES, TYPES } from './config';
import Button from './Button';
import ButtonIcon from './ButtonIcon';
import ButtonSpinnerIcon from './buttonSpinnerIcon';

var createClasses = function createClasses(array, sufix) {
  if (sufix === void 0) {
    sufix = '';
  }

  return array.reduce(function (res, key) {
    var _extends2;

    return _extends({}, res, (_extends2 = {}, _extends2[key] = CLASS + "--" + key + sufix, _extends2));
  }, {});
};

var CLASSES = createClasses([].concat(TYPES, Object.values(DESIGNS), Object.values(ALIGNMENT), MODIFIERS, Object.values(SIZES), ['empty']));
var COLOR_CLASSES = createClasses(COLORS, 'Color');
/**
 * Get props cleaning out AtomButton own props
 * @param  {Object} props
 * @return {Object}
 */

var cleanProps = function cleanProps(props) {
  var newProps = _extends({}, props);

  OWN_PROPS.forEach(function (key) {
    return delete newProps[key];
  });
  return newProps;
};
/**
 * Get modifiers to apply according to props
 * @param  {Object} props
 * @return {Array<String>}
 */


var getModifiers = function getModifiers(props) {
  return Object.keys(props).filter(function (name) {
    return props[name] && MODIFIERS.includes(name);
  });
};

var getPropsWithDefaultValues = function getPropsWithDefaultValues(props) {
  var color = props.color,
      design = props.design,
      _props$alignment = props.alignment,
      alignment = _props$alignment === void 0 ? ALIGNMENT.CENTER : _props$alignment,
      type = props.type; // if color or design are defined, use them with the passed or default value

  if (color || design) {
    if (design !== DESIGNS.LINK) {
      color = color || 'primary';
    }

    design = design || DESIGNS.SOLID;
  } else {
    type = type || 'primary';
  }

  return _extends({
    color: color,
    design: design,
    type: type,
    alignment: alignment
  }, props);
};

var AtomButton = function AtomButton(props) {
  var _cx;

  var _getPropsWithDefaultV = getPropsWithDefaultValues(props),
      color = _getPropsWithDefaultV.color,
      children = _getPropsWithDefaultV.children,
      className = _getPropsWithDefaultV.className,
      focused = _getPropsWithDefaultV.focused,
      groupPosition = _getPropsWithDefaultV.groupPosition,
      leftIcon = _getPropsWithDefaultV.leftIcon,
      rightIcon = _getPropsWithDefaultV.rightIcon,
      size = _getPropsWithDefaultV.size,
      design = _getPropsWithDefaultV.design,
      alignment = _getPropsWithDefaultV.alignment,
      title = _getPropsWithDefaultV.title,
      disabled = _getPropsWithDefaultV.disabled,
      isLoading = _getPropsWithDefaultV.isLoading,
      loadingText = _getPropsWithDefaultV.loadingText,
      type = _getPropsWithDefaultV.type,
      _getPropsWithDefaultV2 = _getPropsWithDefaultV.loader,
      loader = _getPropsWithDefaultV2 === void 0 ? /*#__PURE__*/_jsx(ButtonSpinnerIcon, {}) : _getPropsWithDefaultV2;

  var classNames = cx(CLASS, !type && COLOR_CLASSES[color], !type && CLASSES[design], type && CLASSES[type], alignment && CLASSES[alignment], groupPosition && CLASS + "-group " + CLASS + "-group--" + groupPosition, groupPosition && focused && CLASS + "-group--focused", size && CLASSES[size], getModifiers(_extends({}, props, {
    disabled: disabled || isLoading
  })).map(function (key) {
    return CLASSES[key];
  }), !children && CLASSES.empty, (_cx = {}, _cx[CLASS + "--loading"] = isLoading, _cx), className);
  var newProps = cleanProps(props);
  return /*#__PURE__*/_jsx(Button, _extends({}, newProps, {
    className: classNames,
    title: title,
    disabled: disabled || isLoading,
    children: /*#__PURE__*/_jsx("span", {
      className: CLASS + "-inner",
      children: isLoading ? /*#__PURE__*/_jsxs(_Fragment, {
        children: [/*#__PURE__*/_jsx(ButtonIcon, {
          position: loadingText ? ICON_POSITIONS.LEFT : ICON_POSITIONS.CENTER,
          size: size,
          children: loader
        }), children && loadingText ? loadingText : /*#__PURE__*/_jsx("span", {
          className: CLASS + "-text",
          children: children
        })]
      }) : /*#__PURE__*/_jsxs(_Fragment, {
        children: [/*#__PURE__*/_jsx(ButtonIcon, {
          position: ICON_POSITIONS.LEFT,
          size: size,
          children: leftIcon
        }), leftIcon || rightIcon ? /*#__PURE__*/_jsx("span", {
          className: CLASS + "-text",
          children: children
        }) : children, /*#__PURE__*/_jsx(ButtonIcon, {
          position: ICON_POSITIONS.RIGHT,
          size: size,
          children: rightIcon
        })]
      })
    })
  }));
};

AtomButton.displayName = 'AtomButton';
export default AtomButton;
export { GROUP_POSITIONS as atomButtonGroupPositions };
export { COLORS as atomButtonColors };
export { DESIGNS as atomButtonDesigns };
export { SIZES as atomButtonSizes };
export { TYPES as atomButtonTypes };
export { ALIGNMENT as atomButtonAlignment };
